hstrat.hstrat.HereditaryStratigraphicColumnBundle
=================================================

.. currentmodule:: hstrat.hstrat

.. autoclass:: HereditaryStratigraphicColumnBundle

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HereditaryStratigraphicColumnBundle.Clone
      ~HereditaryStratigraphicColumnBundle.CloneDescendant
      ~HereditaryStratigraphicColumnBundle.DepositStratum
      ~HereditaryStratigraphicColumnBundle.GetNumStrataDeposited
      ~HereditaryStratigraphicColumnBundle.__init__
   
   

   
   
   